@@ -35,6 +35,7 @@ class Count(AggregationPrimitive):
     stack_on_self = False
     default_value = 0
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    description_template = "the number"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type in [Library.DASK, Library.KOALAS]:
@@ -63,6 +64,7 @@ class Sum(AggregationPrimitive):
     stack_on_exclude = [Count]
     default_value = 0
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    description_template = 'the sum of {}'
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type in [Library.DASK, Library.KOALAS]:
@@ -93,6 +95,7 @@ class Mean(AggregationPrimitive):
     input_types = [Numeric]
     return_type = Numeric
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    description_template = "the average of {}"
 
     def __init__(self, skipna=True):
         self.skipna = skipna
@@ -127,6 +130,7 @@ class Mode(AggregationPrimitive):
     name = "mode"
     input_types = [Discrete]
     return_type = None
+    description_template = "the most frequently occurring value of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         def pd_mode(s):
@@ -148,6 +152,7 @@ class Min(AggregationPrimitive):
     return_type = Numeric
     stack_on_self = False
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    description_template = "the minimum of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type in [Library.DASK, Library.KOALAS]:
@@ -169,6 +174,7 @@ class Max(AggregationPrimitive):
     return_type = Numeric
     stack_on_self = False
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    description_template = "the maximum of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type in [Library.DASK, Library.KOALAS]:
@@ -195,6 +201,7 @@ class NumUnique(AggregationPrimitive):
     return_type = Numeric
     stack_on_self = False
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    description_template = "the number of unique elements in {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type == Library.DASK:
@@ -240,6 +247,7 @@ class NumTrue(AggregationPrimitive):
     stack_on = []
     stack_on_exclude = []
     compatibility = [Library.PANDAS, Library.DASK]
+    description_template = "the number of times {} is true"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type == Library.DASK:
@@ -278,6 +286,7 @@ class PercentTrue(AggregationPrimitive):
     stack_on_exclude = []
     default_value = 0
     compatibility = [Library.PANDAS, Library.DASK]
+    description_template = "the percentage of true values in {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type == Library.DASK:
@@ -333,6 +342,11 @@ class NMostCommon(AggregationPrimitive):
     def __init__(self, n=3):
         self.n = n
         self.number_output_features = n
+        self.description_template = [
+            'the {} most common values of {{}}'.format(n),
+            'the most common value of {}',
+            *['the {nth_slice} most common value of {}'] * (n - 1)
+        ]
 
     def get_function(self, agg_type=Library.PANDAS):
         def n_most_common(x):
@@ -373,6 +387,7 @@ class AvgTimeBetween(AggregationPrimitive):
     name = "avg_time_between"
     input_types = [DatetimeTimeIndex]
     return_type = Numeric
+    description_template = "the average time between each of {}"
 
     def __init__(self, unit="seconds"):
         self.unit = unit.lower()
@@ -424,6 +439,7 @@ class Median(AggregationPrimitive):
     name = "median"
     input_types = [Numeric]
     return_type = Numeric
+    description_template = "the median of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         return pd.Series.median
@@ -447,6 +463,7 @@ class Skew(AggregationPrimitive):
     return_type = Numeric
     stack_on = []
     stack_on_self = False
+    description_template = "the skewness of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         return pd.Series.skew
@@ -465,6 +482,7 @@ class Std(AggregationPrimitive):
     return_type = Numeric
     stack_on_self = False
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
+    description_template = "the standard deviation of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type in [Library.DASK, Library.KOALAS]:
@@ -485,6 +503,7 @@ class First(AggregationPrimitive):
     input_types = [Variable]
     return_type = None
     stack_on_self = False
+    description_template = "the first instance of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         def pd_first(x):
@@ -505,6 +524,7 @@ class Last(AggregationPrimitive):
     input_types = [Variable]
     return_type = None
     stack_on_self = False
+    description_template = "the last instance of {}"
 
     def get_function(self, agg_type=Library.PANDAS):
         def pd_last(x):
@@ -530,6 +550,7 @@ class Any(AggregationPrimitive):
     return_type = Boolean
     stack_on_self = False
     compatibility = [Library.PANDAS, Library.DASK]
+    description_template = "whether any of {} are true"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type == Library.DASK:
@@ -561,6 +582,7 @@ class All(AggregationPrimitive):
     return_type = Boolean
     stack_on_self = False
     compatibility = [Library.PANDAS, Library.DASK]
+    description_template = "whether all of {} are true"
 
     def get_function(self, agg_type=Library.PANDAS):
         if agg_type == Library.DASK:
@@ -612,6 +634,7 @@ class TimeSinceLast(AggregationPrimitive):
     input_types = [DatetimeTimeIndex]
     return_type = Numeric
     uses_calc_time = True
+    description_template = "the time since the last {}"
 
     def __init__(self, unit="seconds"):
         self.unit = unit.lower()
@@ -661,6 +684,7 @@ class TimeSinceFirst(AggregationPrimitive):
     input_types = [DatetimeTimeIndex]
     return_type = Numeric
     uses_calc_time = True
+    description_template = "the time since the first {}"
 
     def __init__(self, unit="seconds"):
         self.unit = unit.lower()
@@ -695,6 +719,7 @@ class Trend(AggregationPrimitive):
     name = "trend"
     input_types = [Numeric, DatetimeTimeIndex]
     return_type = Numeric
+    description_template = "the linear trend of {} over time"
 
     def get_function(self, agg_type=Library.PANDAS):
         def pd_trend(y, x):
@@ -778,6 +803,7 @@ class Entropy(AggregationPrimitive):
     input_types = [Categorical]
     return_type = Numeric
     stack_on_self = False
+    description_template = "the entropy of {}"
 
     def __init__(self, dropna=False, base=None):
         self.dropna = dropna
