@@ -24,6 +24,8 @@ class Variable(object):
             it belongs to.
         entity (:class:`.Entity`) : Entity this variable belongs to.
         name (str, optional) : Variable name. Defaults to id.
+        description (str, optional) : Description of what the variable is.
+            Used when describing features with `ft.describe_feature`.
 
     See Also:
         :class:`.Entity`, :class:`.Relationship`, :class:`.BaseEntitySet`
@@ -31,11 +33,12 @@ class Variable(object):
     type_string = ClassNameDescriptor()
     _default_pandas_dtype = object
 
-    def __init__(self, id, entity, name=None):
+    def __init__(self, id, entity, name=None, description=None):
         assert isinstance(id, str), "Variable id must be a string"
         self.id = id
         self._name = name
         self.entity_id = entity.id
+        self._description = description
         assert entity.entityset is not None, "Entity must contain reference to EntitySet"
         self.entity = entity
         if self.id not in self.entity.df:
@@ -94,6 +97,16 @@ class Variable(object):
     def name(self, name):
         self._name = name
 
+    @property
+    def description(self):
+        return self._description if self._description is not None else 'the "{}"'.format(self.name)
+
+    @description.setter
+    def description(self, description):
+        if description != self._description:
+            self.entity.entityset.reset_data_description()
+        self._description = description
+
     @property
     def interesting_values(self):
         return self._interesting_values
@@ -115,6 +128,7 @@ class Variable(object):
             },
             'properties': {
                 'name': self.name,
+                'description': self.description,
                 'entity': self.entity.id,
                 'interesting_values': self._interesting_values.to_json()
             },
